# This is a demo of movies in DocOnce

HPL

#### Apr 15, 2021

Here is a movie in WebM format. Note that in HTML format a WebM movie may actually be the MP4 version of this movie three alternative sources (MP4, WebM, OGG) are inserted in the HTML code by default. The command-line option `--no_mp4_webm_ogg_alternatives` makes the HTML code use exactly the specified movie file.

1D wave in WebM.

Here is the same movie in Ogg format:

1D wave in Ogg.

Here is the same movie in MP4 format:

1D wave in MP4.

Here is the same movie in Flash format:

1D wave in Flash.

And here is a collection of images shown as an animation (`frame_*.png`):

Animated collection of images.

Here is the same collection, but with images in cyberspace, given as URLs:

>     https://hplgit.github.io/animate/..../frame_%04d.png:80->129

Taking images to animate from cyberspace.

The movie above in MPEG format, typeset in a box:

1D wave in MPEG.

Here is the same movie in AVI format:

1D wave in AVI.

Here is the same movie, but with a URL to GitHub:

Here is a YouTube video:

YouTube movie.

And a vimeo video:

Vimeo movie.

Finally, let us demonstrate referencing the movie mov:wave.